@@ -1,7 +1,9 @@
-#[cfg(with_options)]
-use crate::fs::OpenOptions;
-use crate::fs::{Metadata, Permissions};
-use cap_primitives::{ambient_authority, fs::is_file_read_write, AmbientAuthority};
+use crate::fs::{Metadata, OpenOptions, Permissions};
+use cap_primitives::{
+    ambient_authority,
+    fs::{is_file_read_write, open_ambient},
+    AmbientAuthority,
+};
 #[cfg(not(windows))]
 use io_lifetimes::{AsFd, BorrowedFd, FromFd, IntoFd, OwnedFd};
 #[cfg(windows)]
@@ -11,6 +13,7 @@ use std::path::Path;
 use std::{
     fmt, fs,
     io::{self, IoSlice, IoSliceMut, Read, Seek, SeekFrom, Write},
+    path::Path,
     process,
 };
 #[cfg(not(windows))]
@@ -72,8 +75,8 @@ impl File {
         self.std.sync_all()
     }
 
-    /// This function is similar to `sync_all`, except that it may not synchronize
-    /// file metadata to a filesystem.
+    /// This function is similar to `sync_all`, except that it may not
+    /// synchronize file metadata to a filesystem.
     ///
     /// This corresponds to [`std::fs::File::sync_data`].
     #[inline]
@@ -81,8 +84,8 @@ impl File {
         self.std.sync_data()
     }
 
-    /// Truncates or extends the underlying file, updating the size of this file
-    /// to become size.
+    /// Truncates or extends the underlying file, updating the size of this
+    /// file to become size.
     ///
     /// This corresponds to [`std::fs::File::set_len`].
     #[inline]
@@ -98,8 +101,8 @@ impl File {
         metadata_from(&self.std)
     }
 
-    /// Creates a new `File` instance that shares the same underlying file handle as the existing
-    /// `File` instance.
+    /// Creates a new `File` instance that shares the same underlying file
+    /// handle as the existing `File` instance.
     ///
     /// This corresponds to [`std::fs::File::try_clone`].
     #[inline]
@@ -116,6 +119,44 @@ impl File {
         self.std
             .set_permissions(permissions_into_std(&self.std, perm)?)
     }
+
+    /// Constructs a new instance of `Self` in read-only mode by opening the
+    /// given path as a file using the host process' ambient authority.
+    ///
+    /// # Ambient Authority
+    ///
+    /// This function is not sandboxed and may access any path that the host
+    /// process has access to.
+    #[inline]
+    pub fn open_ambient<P: AsRef<Path>>(
+        path: P,
+        ambient_authority: AmbientAuthority,
+    ) -> io::Result<Self> {
+        let std = open_ambient(
+            path.as_ref(),
+            &OpenOptions::new().read(true),
+            ambient_authority,
+        )?;
+        Ok(Self::from_std(std, ambient_authority))
+    }
+
+    /// Constructs a new instance of `Self` with the options specified by
+    /// `options` by opening the given path as a file using the host process'
+    /// ambient authority.
+    ///
+    /// # Ambient Authority
+    ///
+    /// This function is not sandboxed and may access any path that the host
+    /// process has access to.
+    #[inline]
+    pub fn open_ambient_with<P: AsRef<Path>>(
+        path: P,
+        options: &OpenOptions,
+        ambient_authority: AmbientAuthority,
+    ) -> io::Result<Self> {
+        let std = open_ambient(path.as_ref(), options, ambient_authority)?;
+        Ok(Self::from_std(std, ambient_authority))
+    }
 }
 
 #[cfg(not(target_os = "wasi"))]
